==> nextcloud-25.0.11.tgz: nextcloud/apps/activity/l10n/es_DO.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "Home" : "Inicio",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Activity" : "Actividad",
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "No activities" : "No hay actividades",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "Mail" : "Correo",
    "Push" : "Enviar",
    "Notifications" : "Notificaciones",
    "Send email" : "Enviar correo electrónico",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "No activity yet" : "Aún no tiene actividad",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar correos electrónicos de notificación",
    "Choose for which activities you want to get an email or push notification." : "Elija para qué actividades desea recibir un correo electrónico o una notificación automática.",
    "Choose for which activities you want to get a push notification." : "Elija para qué actividades desea recibir una notificación automática.",
    "Send daily activity summary in the morning" : "Enviar resumen de actividad diaria por la mañana.",
    "Default settings" : "Configuraciones predeterminadas",
    "Activity feed" : "Fuente de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "No more events to load" : "No hay más eventos por cargar",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Esta aplicación permite a los usuarios ver acciones relacionadas con sus archivos en Nextcloud. \n\t\tUna vez habilitado, los usuarios verán un nuevo icono \"Actividad\" en su menú de aplicaciones. \n\t\tCuando se hace clic, aparece una nueva página para que los usuarios rastreen la actividad relacionada con los archivos, desde archivos nuevos hasta archivos eliminados, mover, renombrar, actualizaciones y actividad compartida.\n\t\tEl usuario puede configurar sus ajustes de actividad individual en su menú personal. \n\t\tEsto establece el tipo de actividad a registrar, así como si el usuario ve sus propias actividades, \n\t\tsi solo están disponibles en línea y si reciben un resumen por correo electrónico de forma regular. \n\t\tHay más información disponible en la documentación de la actividad.",
    "Activities" : "Actividades",
    "Configure the default notification settings for new users." : "Configure los ajustes de notificación predeterminados para nuevos usuarios."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-26.0.11.tgz: nextcloud/apps/activity/l10n/es_DO.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Activity feed" : "Fuente de actividad",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "No activities" : "No hay actividades",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "Mail" : "Correo",
    "Push" : "Enviar",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "Send email" : "Enviar correo electrónico",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Comentaste",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "No activity yet" : "Aún no tiene actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar correos electrónicos de notificación",
    "Choose for which activities you want to get an email or push notification." : "Elija para qué actividades desea recibir un correo electrónico o una notificación automática.",
    "Choose for which activities you want to get a push notification." : "Elija para qué actividades desea recibir una notificación automática.",
    "Send daily activity summary in the morning" : "Enviar resumen de actividad diaria por la mañana.",
    "Default settings" : "Configuraciones predeterminadas",
    "No more events to load" : "No hay más eventos por cargar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Activities" : "Actividades"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
